package gpsys.cos;

import gpsys.*;
import java.util.Random;

/**
 * <pre>
 *	Vector2Mod10 ConstantVector2Mod10
 * </pre>
 *
 * Creates a Terminal representing an ephemeral random constant of Type
 * Vector2Mod10.
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 * @see			gpsys.Type
 * @see			gpsys.Primitive
 * @see			gpsys.Terminal
 *
 */
public class ConstantVector2Mod10 extends Terminal {
	/**
	 * The value of this constant.
	 */
	public  Vector2Mod10 v;
	/**
	 * The random number generator.
	 */
	private Random rng;

	/**
	 * Create a new ephemeral random Vector2Mod10 constant in the range
	 * (0,0) to (9,9).
	 *
	 * @param rng	The random number generator to be used.
	 */
	public ConstantVector2Mod10(Random rng) {
		this.type = CosSimTypes.Vector2Mod10;
		this.rng	= rng;

		int x = rng.nextInt() % 10;
		x = (x < 0) ? -x : x;

		int y = rng.nextInt() % 10;
		y = (y < 0) ? -y : y;

		v = new Vector2Mod10(x,y);
	}
		
	/**
	* Evaluate this Terminal.
	*
	* @param i	The individual being evaluated.
	* @return	The value of the constant.
	*/
	public final Object evaluateObject(Individual i) {
		return v;
	}

	/**
	* Creates a new Vector2Mod10 constant in exactly the same range as this
	* constant, and using the same random number generator.
	*
	* @return A new Vector2Mod10 constant in exactly the same range.
	*/
	public final Primitive instance() {
		return new ConstantVector2Mod10(rng);
	}

	/**
	* Returns the value of the constant as a String.
	*
	* @return A String representing the value of this constant.
	*/
	public String toString() {
		return v.toString();
	}
}
