package gpsys.cos;

import gpsys.*;
import java.util.Random;

/**
 * The GPParameters class for the terrain robot problem.  Any instance of
 * this class has all the GP parameters correctly set.
 *
 * @version             1.1, 24 Mars 1999
 * @author      <a href="mailto:epierre@e-nef.com">Emmanuel PIERRE</a>
 *                      <address>DEA IARFA,</address>
 */
public class CosSimGPParameters extends GPParameters {
	/**
	 * The terrain to be moveed.
	 */
	public Terrain		terrain;
	/**
	 * The robot to be controlled.
	 */
	public Robot	robot;

	/**
	 * Constructs a GPParameters object for the terrain robot problem.
	 *
	 * @param seed			The seed to be used for the random number generator.
	 *						If a seed value of 0 is supplied, a unique seed is
	 *						generated using the current time.
	 * @param population	The size of the population to be used.
	 * @param generations	The maximum number of generations to be evolved.
	 */
	CosSimGPParameters(long seed, int population, int generations ) {

		this.populationSize		= population;
		this.generations		= generations;

		if (seed == 0)
			rngSeed = System.currentTimeMillis();
		else
			rngSeed = seed;
		rng = new Random(rngSeed);

		pMutation	= 0.05;
		tournamentSize	= 7;

		terrain	= new Terrain(10);	// create an 10x10 terrain
		robot	= new Robot(terrain);	// create a terrainrobot to move above terrain

		adf = new ChromosomeParameters[2];
		// doesn't matter if we initialise in non-conventional order
		// in this case it is positively helpfull !!
		//adf[2] = new CosSimChromosomeParametersADF2(robot, rng);
		adf[0] = new CosSimChromosomeParametersADF0(robot, rng);
		adf[1] = new CosSimChromosomeParametersADF1(robot, rng);
		fitness = new CosSimFitness(terrain, robot);
	}
}
